==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/DataChartAnnotationDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, markType } from "./type";
import { CrosshairLayerDescriptionModule } from "./CrosshairLayerDescriptionModule";
import { CategoryToolTipLayerDescriptionModule } from "./CategoryToolTipLayerDescriptionModule";
import { ItemToolTipLayerDescriptionModule } from "./ItemToolTipLayerDescriptionModule";
import { CategoryItemHighlightLayerDescriptionModule } from "./CategoryItemHighlightLayerDescriptionModule";
import { CategoryHighlightLayerDescriptionModule } from "./CategoryHighlightLayerDescriptionModule";
import { FinalValueLayerDescriptionModule } from "./FinalValueLayerDescriptionModule";
import { CalloutLayerDescriptionModule } from "./CalloutLayerDescriptionModule";
import { DataToolTipLayerDescriptionModule } from "./DataToolTipLayerDescriptionModule";
/**
 * @hidden
 */
var DataChartAnnotationDescriptionModule = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(DataChartAnnotationDescriptionModule, _super);
    function DataChartAnnotationDescriptionModule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataChartAnnotationDescriptionModule.register = function (a) {
        CrosshairLayerDescriptionModule.register(a);
        CategoryToolTipLayerDescriptionModule.register(a);
        ItemToolTipLayerDescriptionModule.register(a);
        CategoryItemHighlightLayerDescriptionModule.register(a);
        CategoryHighlightLayerDescriptionModule.register(a);
        FinalValueLayerDescriptionModule.register(a);
        CalloutLayerDescriptionModule.register(a);
        DataToolTipLayerDescriptionModule.register(a);
    };
    DataChartAnnotationDescriptionModule.$t = markType(DataChartAnnotationDescriptionModule, 'DataChartAnnotationDescriptionModule');
    return DataChartAnnotationDescriptionModule;
}(Base));
export { DataChartAnnotationDescriptionModule };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/DataChartAnnotationDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "./type";
import { CrosshairLayerDescriptionModule } from "./CrosshairLayerDescriptionModule";
import { CategoryToolTipLayerDescriptionModule } from "./CategoryToolTipLayerDescriptionModule";
import { ItemToolTipLayerDescriptionModule } from "./ItemToolTipLayerDescriptionModule";
import { CategoryItemHighlightLayerDescriptionModule } from "./CategoryItemHighlightLayerDescriptionModule";
import { CategoryHighlightLayerDescriptionModule } from "./CategoryHighlightLayerDescriptionModule";
import { FinalValueLayerDescriptionModule } from "./FinalValueLayerDescriptionModule";
import { CalloutLayerDescriptionModule } from "./CalloutLayerDescriptionModule";
import { DataToolTipLayerDescriptionModule } from "./DataToolTipLayerDescriptionModule";
import { ValueLayerDescriptionModule } from "./ValueLayerDescriptionModule";
import { TrendLineLayerDescriptionModule } from "./TrendLineLayerDescriptionModule";
/**
 * @hidden
 */
var DataChartAnnotationDescriptionModule = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataChartAnnotationDescriptionModule, _super);
    function DataChartAnnotationDescriptionModule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataChartAnnotationDescriptionModule.register = function (a) {
        CrosshairLayerDescriptionModule.register(a);
        CategoryToolTipLayerDescriptionModule.register(a);
        ItemToolTipLayerDescriptionModule.register(a);
        CategoryItemHighlightLayerDescriptionModule.register(a);
        CategoryHighlightLayerDescriptionModule.register(a);
        FinalValueLayerDescriptionModule.register(a);
        CalloutLayerDescriptionModule.register(a);
        DataToolTipLayerDescriptionModule.register(a);
        ValueLayerDescriptionModule.register(a);
        TrendLineLayerDescriptionModule.register(a);
    };
    DataChartAnnotationDescriptionModule.$t = markType(DataChartAnnotationDescriptionModule, 'DataChartAnnotationDescriptionModule');
    return DataChartAnnotationDescriptionModule;
}(Base));
export { DataChartAnnotationDescriptionModule };
